Documentation
¶
Overview ¶
Package twilio provides message notification integration for Twilio (Message Service).
Usage:
package main
import (
"context"
"log"
"github.com/nikoksr/notify"
"github.com/nikoksr/notify/service/twilio"
)
func main() {
twilioSvc, err := twilio.New("account_sid", "auth_token", "your_phone_number")
if err != nil {
log.Fatalf("twilio.New() failed: %s", err.Error())
}
twilioSvc.AddReceivers("recipient_phone_number")
notifier := notify.New()
notifier.UseServices(twilioSvc)
err = notifier.Send(context.Background(), "subject", "message")
if err != nil {
log.Fatalf("notifier.Send() failed: %s", err.Error())
}
log.Println("notification sent")
}
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service encapsulates the Twilio Message Service client along with internal state for storing recipient phone numbers.
func (*Service) AddReceivers ¶
AddReceivers takes strings of recipient phone numbers and appends them to the internal phone numbers slice. The Send method will send a given message to all those phone numbers.
Click to show internal directories.
Click to hide internal directories.